@@ -37,12 +37,12 @@ namespace zypp
    *
    * \see PluginScript
    */
-  class PluginFrame
+  class ZYPP_TESTS PluginFrame
   {
     friend std::ostream & operator<<( std::ostream & str, const PluginFrame & obj );
     friend bool operator==( const PluginFrame & lhs, const PluginFrame & rhs );
 
-    typedef const std::initializer_list<std::pair<std::string,std::string>> & HeaderInitializerList;
+    using HeaderInitializerList = const std::initializer_list<std::pair<std::string, std::string>> &;
 
     public:
       /** "ACK" command. */
@@ -54,7 +54,7 @@ namespace zypp
 
     public:
       /** Default exception type */
-      typedef PluginFrameException Exception;
+      using Exception = PluginFrameException;
 
       /** Default ctor (empty frame) */
       PluginFrame();
@@ -67,7 +67,7 @@ namespace zypp
       /** Ctor taking command and body
        * \throw PluginFrameException If \ref setCommand throws
        */
-      PluginFrame( const std::string & command_r, const std::string & body_r );
+      PluginFrame(const std::string & command_r, std::string body_r );
 
       /** Ctor taking the command and a HeaderInitializerList
        * \throw PluginFrameException If \ref setCommand throws
@@ -77,7 +77,7 @@ namespace zypp
       /** Ctor taking command, body and a HeaderInitializerList
        * \throw PluginFrameException If \ref setCommand throws
        */
-      PluginFrame( const std::string & command_r, const std::string & body_r, HeaderInitializerList contents_r );
+      PluginFrame(const std::string & command_r, std::string body_r, HeaderInitializerList contents_r );
 
       /** Ctor reading frame data from a stream
        * \throw PluginFrameException On error reading from stream
@@ -132,10 +132,10 @@ namespace zypp
 
     public:
       /** The header list */
-      typedef std::multimap<std::string, std::string> HeaderList;
+      using HeaderList = std::multimap<std::string, std::string>;
 
       /** Header list iterator */
-      typedef HeaderList::const_iterator HeaderListIterator;
+      using HeaderListIterator = HeaderList::const_iterator;
 
     private:
       /** Modifyalble header list for internal use only. */
@@ -254,7 +254,7 @@ namespace zypp
   };
 
   /** \relates PluginFrame Stream output for logging */
-  std::ostream & operator<<( std::ostream & str, const PluginFrame & obj );
+  std::ostream & operator<<( std::ostream & str, const PluginFrame & obj ) ZYPP_TESTS;
 
   /** \relates PluginFrame Stream output writing all data for logging (no throw) */
   inline std::ostream & dumpOn( std::ostream & str, const PluginFrame & obj )
@@ -265,7 +265,7 @@ namespace zypp
   { return PluginFrame::readFrom( str, obj ); }
 
   /** \relates PluginFrame Comparison based on content. */
-  bool operator==( const PluginFrame & lhs, const PluginFrame & rhs );
+  bool operator==( const PluginFrame & lhs, const PluginFrame & rhs ) ZYPP_TESTS;
 
   /** \relates PluginFrame Comparison based on content. */
   inline bool operator!=( const PluginFrame & lhs, const PluginFrame & rhs )
