@@ -26,13 +26,13 @@ namespace zypp
   //	CLASS NAME : PluginFrameException
   //
   /** Base class for \ref PluginFrame \ref Exception. */
-  class PluginFrameException : public Exception
+  class ZYPP_API PluginFrameException : public Exception
   {
     public:
       PluginFrameException();
       PluginFrameException( const std::string & msg_r );
       PluginFrameException( const std::string & msg_r, const std::string & hist_r );
-      virtual ~PluginFrameException() throw();
+      ~PluginFrameException() throw() override;
   };
   ///////////////////////////////////////////////////////////////////
 
