@@ -48,7 +48,7 @@ namespace zypp
      * Repeating the \c baseurl= tag on each line is also accepted, but when the
      * file has to be written, the preferred style is used.
      */
-    class RepoFileReader
+    class ZYPP_TESTS RepoFileReader
     {
       friend std::ostream & operator<<( std::ostream & str, const RepoFileReader & obj );
     public:
@@ -61,7 +61,7 @@ namespace zypp
       * Return false from the callback to get a \ref AbortRequestException
       * to be thrown and the processing to be cancelled.
       */
-      typedef function< bool( const RepoInfo & )> ProcessRepo;
+      using ProcessRepo = function<bool (const RepoInfo &)>;
 
       /** Implementation  */
       class Impl;
@@ -79,7 +79,7 @@ namespace zypp
       *
       */
       RepoFileReader( const Pathname & repo_file,
-                      const ProcessRepo & callback,
+                      ProcessRepo  callback,
                       const ProgressData::ReceiverFnc &progress = ProgressData::ReceiverFnc() );
 
      /**
@@ -94,7 +94,7 @@ namespace zypp
       *
       */
       RepoFileReader( const InputStream &is,
-                      const ProcessRepo & callback,
+                      ProcessRepo  callback,
                       const ProgressData::ReceiverFnc &progress = ProgressData::ReceiverFnc() );
 
       /**
